# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ProjectLevelNotificationsArgs', 'ProjectLevelNotifications']

@pulumi.input_type
class ProjectLevelNotificationsArgs:
    def __init__(__self__, *,
                 project: pulumi.Input[str],
                 close_issue: Optional[pulumi.Input[bool]] = None,
                 close_merge_request: Optional[pulumi.Input[bool]] = None,
                 failed_pipeline: Optional[pulumi.Input[bool]] = None,
                 fixed_pipeline: Optional[pulumi.Input[bool]] = None,
                 issue_due: Optional[pulumi.Input[bool]] = None,
                 level: Optional[pulumi.Input[str]] = None,
                 merge_merge_request: Optional[pulumi.Input[bool]] = None,
                 merge_when_pipeline_succeeds: Optional[pulumi.Input[bool]] = None,
                 moved_project: Optional[pulumi.Input[bool]] = None,
                 new_issue: Optional[pulumi.Input[bool]] = None,
                 new_merge_request: Optional[pulumi.Input[bool]] = None,
                 new_note: Optional[pulumi.Input[bool]] = None,
                 push_to_merge_request: Optional[pulumi.Input[bool]] = None,
                 reassign_issue: Optional[pulumi.Input[bool]] = None,
                 reassign_merge_request: Optional[pulumi.Input[bool]] = None,
                 reopen_issue: Optional[pulumi.Input[bool]] = None,
                 reopen_merge_request: Optional[pulumi.Input[bool]] = None,
                 success_pipeline: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a ProjectLevelNotifications resource.
        :param pulumi.Input[str] project: The ID or URL-encoded path of a project where notifications will be configured.
        :param pulumi.Input[bool] close_issue: Enable notifications for closed issues. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] close_merge_request: Enable notifications for closed merge requests. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] failed_pipeline: Enable notifications for failed pipelines. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] fixed_pipeline: Enable notifications for fixed pipelines. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] issue_due: Enable notifications for due issues. Can only be used when `level` is `custom`.
        :param pulumi.Input[str] level: The level of the notification. Valid values are: `disabled`, `participating`, `watch`, `global`, `mention`, `custom`.
        :param pulumi.Input[bool] merge_merge_request: Enable notifications for merged merge requests. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] merge_when_pipeline_succeeds: Enable notifications for merged merge requests when the pipeline succeeds. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] moved_project: Enable notifications for moved projects. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] new_issue: Enable notifications for new issues. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] new_merge_request: Enable notifications for new merge requests. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] new_note: Enable notifications for new notes on merge requests. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] push_to_merge_request: Enable notifications for push to merge request branches. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] reassign_issue: Enable notifications for issue reassignments. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] reassign_merge_request: Enable notifications for merge request reassignments. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] reopen_issue: Enable notifications for reopened issues. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] reopen_merge_request: Enable notifications for reopened merge requests. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] success_pipeline: Enable notifications for successful pipelines. Can only be used when `level` is `custom`.
        """
        pulumi.set(__self__, "project", project)
        if close_issue is not None:
            pulumi.set(__self__, "close_issue", close_issue)
        if close_merge_request is not None:
            pulumi.set(__self__, "close_merge_request", close_merge_request)
        if failed_pipeline is not None:
            pulumi.set(__self__, "failed_pipeline", failed_pipeline)
        if fixed_pipeline is not None:
            pulumi.set(__self__, "fixed_pipeline", fixed_pipeline)
        if issue_due is not None:
            pulumi.set(__self__, "issue_due", issue_due)
        if level is not None:
            pulumi.set(__self__, "level", level)
        if merge_merge_request is not None:
            pulumi.set(__self__, "merge_merge_request", merge_merge_request)
        if merge_when_pipeline_succeeds is not None:
            pulumi.set(__self__, "merge_when_pipeline_succeeds", merge_when_pipeline_succeeds)
        if moved_project is not None:
            pulumi.set(__self__, "moved_project", moved_project)
        if new_issue is not None:
            pulumi.set(__self__, "new_issue", new_issue)
        if new_merge_request is not None:
            pulumi.set(__self__, "new_merge_request", new_merge_request)
        if new_note is not None:
            pulumi.set(__self__, "new_note", new_note)
        if push_to_merge_request is not None:
            pulumi.set(__self__, "push_to_merge_request", push_to_merge_request)
        if reassign_issue is not None:
            pulumi.set(__self__, "reassign_issue", reassign_issue)
        if reassign_merge_request is not None:
            pulumi.set(__self__, "reassign_merge_request", reassign_merge_request)
        if reopen_issue is not None:
            pulumi.set(__self__, "reopen_issue", reopen_issue)
        if reopen_merge_request is not None:
            pulumi.set(__self__, "reopen_merge_request", reopen_merge_request)
        if success_pipeline is not None:
            pulumi.set(__self__, "success_pipeline", success_pipeline)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Input[str]:
        """
        The ID or URL-encoded path of a project where notifications will be configured.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[str]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter(name="closeIssue")
    def close_issue(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for closed issues. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "close_issue")

    @close_issue.setter
    def close_issue(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "close_issue", value)

    @property
    @pulumi.getter(name="closeMergeRequest")
    def close_merge_request(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for closed merge requests. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "close_merge_request")

    @close_merge_request.setter
    def close_merge_request(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "close_merge_request", value)

    @property
    @pulumi.getter(name="failedPipeline")
    def failed_pipeline(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for failed pipelines. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "failed_pipeline")

    @failed_pipeline.setter
    def failed_pipeline(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "failed_pipeline", value)

    @property
    @pulumi.getter(name="fixedPipeline")
    def fixed_pipeline(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for fixed pipelines. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "fixed_pipeline")

    @fixed_pipeline.setter
    def fixed_pipeline(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "fixed_pipeline", value)

    @property
    @pulumi.getter(name="issueDue")
    def issue_due(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for due issues. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "issue_due")

    @issue_due.setter
    def issue_due(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "issue_due", value)

    @property
    @pulumi.getter
    def level(self) -> Optional[pulumi.Input[str]]:
        """
        The level of the notification. Valid values are: `disabled`, `participating`, `watch`, `global`, `mention`, `custom`.
        """
        return pulumi.get(self, "level")

    @level.setter
    def level(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "level", value)

    @property
    @pulumi.getter(name="mergeMergeRequest")
    def merge_merge_request(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for merged merge requests. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "merge_merge_request")

    @merge_merge_request.setter
    def merge_merge_request(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "merge_merge_request", value)

    @property
    @pulumi.getter(name="mergeWhenPipelineSucceeds")
    def merge_when_pipeline_succeeds(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for merged merge requests when the pipeline succeeds. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "merge_when_pipeline_succeeds")

    @merge_when_pipeline_succeeds.setter
    def merge_when_pipeline_succeeds(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "merge_when_pipeline_succeeds", value)

    @property
    @pulumi.getter(name="movedProject")
    def moved_project(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for moved projects. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "moved_project")

    @moved_project.setter
    def moved_project(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "moved_project", value)

    @property
    @pulumi.getter(name="newIssue")
    def new_issue(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for new issues. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "new_issue")

    @new_issue.setter
    def new_issue(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "new_issue", value)

    @property
    @pulumi.getter(name="newMergeRequest")
    def new_merge_request(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for new merge requests. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "new_merge_request")

    @new_merge_request.setter
    def new_merge_request(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "new_merge_request", value)

    @property
    @pulumi.getter(name="newNote")
    def new_note(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for new notes on merge requests. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "new_note")

    @new_note.setter
    def new_note(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "new_note", value)

    @property
    @pulumi.getter(name="pushToMergeRequest")
    def push_to_merge_request(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for push to merge request branches. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "push_to_merge_request")

    @push_to_merge_request.setter
    def push_to_merge_request(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "push_to_merge_request", value)

    @property
    @pulumi.getter(name="reassignIssue")
    def reassign_issue(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for issue reassignments. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "reassign_issue")

    @reassign_issue.setter
    def reassign_issue(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "reassign_issue", value)

    @property
    @pulumi.getter(name="reassignMergeRequest")
    def reassign_merge_request(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for merge request reassignments. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "reassign_merge_request")

    @reassign_merge_request.setter
    def reassign_merge_request(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "reassign_merge_request", value)

    @property
    @pulumi.getter(name="reopenIssue")
    def reopen_issue(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for reopened issues. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "reopen_issue")

    @reopen_issue.setter
    def reopen_issue(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "reopen_issue", value)

    @property
    @pulumi.getter(name="reopenMergeRequest")
    def reopen_merge_request(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for reopened merge requests. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "reopen_merge_request")

    @reopen_merge_request.setter
    def reopen_merge_request(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "reopen_merge_request", value)

    @property
    @pulumi.getter(name="successPipeline")
    def success_pipeline(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for successful pipelines. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "success_pipeline")

    @success_pipeline.setter
    def success_pipeline(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "success_pipeline", value)


@pulumi.input_type
class _ProjectLevelNotificationsState:
    def __init__(__self__, *,
                 close_issue: Optional[pulumi.Input[bool]] = None,
                 close_merge_request: Optional[pulumi.Input[bool]] = None,
                 failed_pipeline: Optional[pulumi.Input[bool]] = None,
                 fixed_pipeline: Optional[pulumi.Input[bool]] = None,
                 issue_due: Optional[pulumi.Input[bool]] = None,
                 level: Optional[pulumi.Input[str]] = None,
                 merge_merge_request: Optional[pulumi.Input[bool]] = None,
                 merge_when_pipeline_succeeds: Optional[pulumi.Input[bool]] = None,
                 moved_project: Optional[pulumi.Input[bool]] = None,
                 new_issue: Optional[pulumi.Input[bool]] = None,
                 new_merge_request: Optional[pulumi.Input[bool]] = None,
                 new_note: Optional[pulumi.Input[bool]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 push_to_merge_request: Optional[pulumi.Input[bool]] = None,
                 reassign_issue: Optional[pulumi.Input[bool]] = None,
                 reassign_merge_request: Optional[pulumi.Input[bool]] = None,
                 reopen_issue: Optional[pulumi.Input[bool]] = None,
                 reopen_merge_request: Optional[pulumi.Input[bool]] = None,
                 success_pipeline: Optional[pulumi.Input[bool]] = None):
        """
        Input properties used for looking up and filtering ProjectLevelNotifications resources.
        :param pulumi.Input[bool] close_issue: Enable notifications for closed issues. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] close_merge_request: Enable notifications for closed merge requests. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] failed_pipeline: Enable notifications for failed pipelines. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] fixed_pipeline: Enable notifications for fixed pipelines. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] issue_due: Enable notifications for due issues. Can only be used when `level` is `custom`.
        :param pulumi.Input[str] level: The level of the notification. Valid values are: `disabled`, `participating`, `watch`, `global`, `mention`, `custom`.
        :param pulumi.Input[bool] merge_merge_request: Enable notifications for merged merge requests. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] merge_when_pipeline_succeeds: Enable notifications for merged merge requests when the pipeline succeeds. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] moved_project: Enable notifications for moved projects. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] new_issue: Enable notifications for new issues. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] new_merge_request: Enable notifications for new merge requests. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] new_note: Enable notifications for new notes on merge requests. Can only be used when `level` is `custom`.
        :param pulumi.Input[str] project: The ID or URL-encoded path of a project where notifications will be configured.
        :param pulumi.Input[bool] push_to_merge_request: Enable notifications for push to merge request branches. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] reassign_issue: Enable notifications for issue reassignments. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] reassign_merge_request: Enable notifications for merge request reassignments. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] reopen_issue: Enable notifications for reopened issues. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] reopen_merge_request: Enable notifications for reopened merge requests. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] success_pipeline: Enable notifications for successful pipelines. Can only be used when `level` is `custom`.
        """
        if close_issue is not None:
            pulumi.set(__self__, "close_issue", close_issue)
        if close_merge_request is not None:
            pulumi.set(__self__, "close_merge_request", close_merge_request)
        if failed_pipeline is not None:
            pulumi.set(__self__, "failed_pipeline", failed_pipeline)
        if fixed_pipeline is not None:
            pulumi.set(__self__, "fixed_pipeline", fixed_pipeline)
        if issue_due is not None:
            pulumi.set(__self__, "issue_due", issue_due)
        if level is not None:
            pulumi.set(__self__, "level", level)
        if merge_merge_request is not None:
            pulumi.set(__self__, "merge_merge_request", merge_merge_request)
        if merge_when_pipeline_succeeds is not None:
            pulumi.set(__self__, "merge_when_pipeline_succeeds", merge_when_pipeline_succeeds)
        if moved_project is not None:
            pulumi.set(__self__, "moved_project", moved_project)
        if new_issue is not None:
            pulumi.set(__self__, "new_issue", new_issue)
        if new_merge_request is not None:
            pulumi.set(__self__, "new_merge_request", new_merge_request)
        if new_note is not None:
            pulumi.set(__self__, "new_note", new_note)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if push_to_merge_request is not None:
            pulumi.set(__self__, "push_to_merge_request", push_to_merge_request)
        if reassign_issue is not None:
            pulumi.set(__self__, "reassign_issue", reassign_issue)
        if reassign_merge_request is not None:
            pulumi.set(__self__, "reassign_merge_request", reassign_merge_request)
        if reopen_issue is not None:
            pulumi.set(__self__, "reopen_issue", reopen_issue)
        if reopen_merge_request is not None:
            pulumi.set(__self__, "reopen_merge_request", reopen_merge_request)
        if success_pipeline is not None:
            pulumi.set(__self__, "success_pipeline", success_pipeline)

    @property
    @pulumi.getter(name="closeIssue")
    def close_issue(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for closed issues. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "close_issue")

    @close_issue.setter
    def close_issue(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "close_issue", value)

    @property
    @pulumi.getter(name="closeMergeRequest")
    def close_merge_request(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for closed merge requests. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "close_merge_request")

    @close_merge_request.setter
    def close_merge_request(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "close_merge_request", value)

    @property
    @pulumi.getter(name="failedPipeline")
    def failed_pipeline(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for failed pipelines. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "failed_pipeline")

    @failed_pipeline.setter
    def failed_pipeline(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "failed_pipeline", value)

    @property
    @pulumi.getter(name="fixedPipeline")
    def fixed_pipeline(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for fixed pipelines. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "fixed_pipeline")

    @fixed_pipeline.setter
    def fixed_pipeline(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "fixed_pipeline", value)

    @property
    @pulumi.getter(name="issueDue")
    def issue_due(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for due issues. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "issue_due")

    @issue_due.setter
    def issue_due(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "issue_due", value)

    @property
    @pulumi.getter
    def level(self) -> Optional[pulumi.Input[str]]:
        """
        The level of the notification. Valid values are: `disabled`, `participating`, `watch`, `global`, `mention`, `custom`.
        """
        return pulumi.get(self, "level")

    @level.setter
    def level(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "level", value)

    @property
    @pulumi.getter(name="mergeMergeRequest")
    def merge_merge_request(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for merged merge requests. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "merge_merge_request")

    @merge_merge_request.setter
    def merge_merge_request(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "merge_merge_request", value)

    @property
    @pulumi.getter(name="mergeWhenPipelineSucceeds")
    def merge_when_pipeline_succeeds(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for merged merge requests when the pipeline succeeds. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "merge_when_pipeline_succeeds")

    @merge_when_pipeline_succeeds.setter
    def merge_when_pipeline_succeeds(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "merge_when_pipeline_succeeds", value)

    @property
    @pulumi.getter(name="movedProject")
    def moved_project(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for moved projects. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "moved_project")

    @moved_project.setter
    def moved_project(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "moved_project", value)

    @property
    @pulumi.getter(name="newIssue")
    def new_issue(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for new issues. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "new_issue")

    @new_issue.setter
    def new_issue(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "new_issue", value)

    @property
    @pulumi.getter(name="newMergeRequest")
    def new_merge_request(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for new merge requests. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "new_merge_request")

    @new_merge_request.setter
    def new_merge_request(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "new_merge_request", value)

    @property
    @pulumi.getter(name="newNote")
    def new_note(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for new notes on merge requests. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "new_note")

    @new_note.setter
    def new_note(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "new_note", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        The ID or URL-encoded path of a project where notifications will be configured.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter(name="pushToMergeRequest")
    def push_to_merge_request(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for push to merge request branches. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "push_to_merge_request")

    @push_to_merge_request.setter
    def push_to_merge_request(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "push_to_merge_request", value)

    @property
    @pulumi.getter(name="reassignIssue")
    def reassign_issue(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for issue reassignments. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "reassign_issue")

    @reassign_issue.setter
    def reassign_issue(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "reassign_issue", value)

    @property
    @pulumi.getter(name="reassignMergeRequest")
    def reassign_merge_request(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for merge request reassignments. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "reassign_merge_request")

    @reassign_merge_request.setter
    def reassign_merge_request(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "reassign_merge_request", value)

    @property
    @pulumi.getter(name="reopenIssue")
    def reopen_issue(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for reopened issues. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "reopen_issue")

    @reopen_issue.setter
    def reopen_issue(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "reopen_issue", value)

    @property
    @pulumi.getter(name="reopenMergeRequest")
    def reopen_merge_request(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for reopened merge requests. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "reopen_merge_request")

    @reopen_merge_request.setter
    def reopen_merge_request(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "reopen_merge_request", value)

    @property
    @pulumi.getter(name="successPipeline")
    def success_pipeline(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for successful pipelines. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "success_pipeline")

    @success_pipeline.setter
    def success_pipeline(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "success_pipeline", value)


class ProjectLevelNotifications(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 close_issue: Optional[pulumi.Input[bool]] = None,
                 close_merge_request: Optional[pulumi.Input[bool]] = None,
                 failed_pipeline: Optional[pulumi.Input[bool]] = None,
                 fixed_pipeline: Optional[pulumi.Input[bool]] = None,
                 issue_due: Optional[pulumi.Input[bool]] = None,
                 level: Optional[pulumi.Input[str]] = None,
                 merge_merge_request: Optional[pulumi.Input[bool]] = None,
                 merge_when_pipeline_succeeds: Optional[pulumi.Input[bool]] = None,
                 moved_project: Optional[pulumi.Input[bool]] = None,
                 new_issue: Optional[pulumi.Input[bool]] = None,
                 new_merge_request: Optional[pulumi.Input[bool]] = None,
                 new_note: Optional[pulumi.Input[bool]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 push_to_merge_request: Optional[pulumi.Input[bool]] = None,
                 reassign_issue: Optional[pulumi.Input[bool]] = None,
                 reassign_merge_request: Optional[pulumi.Input[bool]] = None,
                 reopen_issue: Optional[pulumi.Input[bool]] = None,
                 reopen_merge_request: Optional[pulumi.Input[bool]] = None,
                 success_pipeline: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        """
        The `ProjectLevelNotifications` resource allows to manage notifications for a project.

        > While the API supports both groups and projects, this resource only supports projects currently.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/notification_settings/#group--project-level-notification-settings)

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] close_issue: Enable notifications for closed issues. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] close_merge_request: Enable notifications for closed merge requests. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] failed_pipeline: Enable notifications for failed pipelines. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] fixed_pipeline: Enable notifications for fixed pipelines. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] issue_due: Enable notifications for due issues. Can only be used when `level` is `custom`.
        :param pulumi.Input[str] level: The level of the notification. Valid values are: `disabled`, `participating`, `watch`, `global`, `mention`, `custom`.
        :param pulumi.Input[bool] merge_merge_request: Enable notifications for merged merge requests. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] merge_when_pipeline_succeeds: Enable notifications for merged merge requests when the pipeline succeeds. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] moved_project: Enable notifications for moved projects. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] new_issue: Enable notifications for new issues. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] new_merge_request: Enable notifications for new merge requests. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] new_note: Enable notifications for new notes on merge requests. Can only be used when `level` is `custom`.
        :param pulumi.Input[str] project: The ID or URL-encoded path of a project where notifications will be configured.
        :param pulumi.Input[bool] push_to_merge_request: Enable notifications for push to merge request branches. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] reassign_issue: Enable notifications for issue reassignments. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] reassign_merge_request: Enable notifications for merge request reassignments. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] reopen_issue: Enable notifications for reopened issues. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] reopen_merge_request: Enable notifications for reopened merge requests. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] success_pipeline: Enable notifications for successful pipelines. Can only be used when `level` is `custom`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectLevelNotificationsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `ProjectLevelNotifications` resource allows to manage notifications for a project.

        > While the API supports both groups and projects, this resource only supports projects currently.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/notification_settings/#group--project-level-notification-settings)

        :param str resource_name: The name of the resource.
        :param ProjectLevelNotificationsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectLevelNotificationsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 close_issue: Optional[pulumi.Input[bool]] = None,
                 close_merge_request: Optional[pulumi.Input[bool]] = None,
                 failed_pipeline: Optional[pulumi.Input[bool]] = None,
                 fixed_pipeline: Optional[pulumi.Input[bool]] = None,
                 issue_due: Optional[pulumi.Input[bool]] = None,
                 level: Optional[pulumi.Input[str]] = None,
                 merge_merge_request: Optional[pulumi.Input[bool]] = None,
                 merge_when_pipeline_succeeds: Optional[pulumi.Input[bool]] = None,
                 moved_project: Optional[pulumi.Input[bool]] = None,
                 new_issue: Optional[pulumi.Input[bool]] = None,
                 new_merge_request: Optional[pulumi.Input[bool]] = None,
                 new_note: Optional[pulumi.Input[bool]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 push_to_merge_request: Optional[pulumi.Input[bool]] = None,
                 reassign_issue: Optional[pulumi.Input[bool]] = None,
                 reassign_merge_request: Optional[pulumi.Input[bool]] = None,
                 reopen_issue: Optional[pulumi.Input[bool]] = None,
                 reopen_merge_request: Optional[pulumi.Input[bool]] = None,
                 success_pipeline: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectLevelNotificationsArgs.__new__(ProjectLevelNotificationsArgs)

            __props__.__dict__["close_issue"] = close_issue
            __props__.__dict__["close_merge_request"] = close_merge_request
            __props__.__dict__["failed_pipeline"] = failed_pipeline
            __props__.__dict__["fixed_pipeline"] = fixed_pipeline
            __props__.__dict__["issue_due"] = issue_due
            __props__.__dict__["level"] = level
            __props__.__dict__["merge_merge_request"] = merge_merge_request
            __props__.__dict__["merge_when_pipeline_succeeds"] = merge_when_pipeline_succeeds
            __props__.__dict__["moved_project"] = moved_project
            __props__.__dict__["new_issue"] = new_issue
            __props__.__dict__["new_merge_request"] = new_merge_request
            __props__.__dict__["new_note"] = new_note
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            __props__.__dict__["push_to_merge_request"] = push_to_merge_request
            __props__.__dict__["reassign_issue"] = reassign_issue
            __props__.__dict__["reassign_merge_request"] = reassign_merge_request
            __props__.__dict__["reopen_issue"] = reopen_issue
            __props__.__dict__["reopen_merge_request"] = reopen_merge_request
            __props__.__dict__["success_pipeline"] = success_pipeline
        super(ProjectLevelNotifications, __self__).__init__(
            'gitlab:index/projectLevelNotifications:ProjectLevelNotifications',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            close_issue: Optional[pulumi.Input[bool]] = None,
            close_merge_request: Optional[pulumi.Input[bool]] = None,
            failed_pipeline: Optional[pulumi.Input[bool]] = None,
            fixed_pipeline: Optional[pulumi.Input[bool]] = None,
            issue_due: Optional[pulumi.Input[bool]] = None,
            level: Optional[pulumi.Input[str]] = None,
            merge_merge_request: Optional[pulumi.Input[bool]] = None,
            merge_when_pipeline_succeeds: Optional[pulumi.Input[bool]] = None,
            moved_project: Optional[pulumi.Input[bool]] = None,
            new_issue: Optional[pulumi.Input[bool]] = None,
            new_merge_request: Optional[pulumi.Input[bool]] = None,
            new_note: Optional[pulumi.Input[bool]] = None,
            project: Optional[pulumi.Input[str]] = None,
            push_to_merge_request: Optional[pulumi.Input[bool]] = None,
            reassign_issue: Optional[pulumi.Input[bool]] = None,
            reassign_merge_request: Optional[pulumi.Input[bool]] = None,
            reopen_issue: Optional[pulumi.Input[bool]] = None,
            reopen_merge_request: Optional[pulumi.Input[bool]] = None,
            success_pipeline: Optional[pulumi.Input[bool]] = None) -> 'ProjectLevelNotifications':
        """
        Get an existing ProjectLevelNotifications resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] close_issue: Enable notifications for closed issues. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] close_merge_request: Enable notifications for closed merge requests. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] failed_pipeline: Enable notifications for failed pipelines. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] fixed_pipeline: Enable notifications for fixed pipelines. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] issue_due: Enable notifications for due issues. Can only be used when `level` is `custom`.
        :param pulumi.Input[str] level: The level of the notification. Valid values are: `disabled`, `participating`, `watch`, `global`, `mention`, `custom`.
        :param pulumi.Input[bool] merge_merge_request: Enable notifications for merged merge requests. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] merge_when_pipeline_succeeds: Enable notifications for merged merge requests when the pipeline succeeds. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] moved_project: Enable notifications for moved projects. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] new_issue: Enable notifications for new issues. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] new_merge_request: Enable notifications for new merge requests. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] new_note: Enable notifications for new notes on merge requests. Can only be used when `level` is `custom`.
        :param pulumi.Input[str] project: The ID or URL-encoded path of a project where notifications will be configured.
        :param pulumi.Input[bool] push_to_merge_request: Enable notifications for push to merge request branches. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] reassign_issue: Enable notifications for issue reassignments. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] reassign_merge_request: Enable notifications for merge request reassignments. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] reopen_issue: Enable notifications for reopened issues. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] reopen_merge_request: Enable notifications for reopened merge requests. Can only be used when `level` is `custom`.
        :param pulumi.Input[bool] success_pipeline: Enable notifications for successful pipelines. Can only be used when `level` is `custom`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectLevelNotificationsState.__new__(_ProjectLevelNotificationsState)

        __props__.__dict__["close_issue"] = close_issue
        __props__.__dict__["close_merge_request"] = close_merge_request
        __props__.__dict__["failed_pipeline"] = failed_pipeline
        __props__.__dict__["fixed_pipeline"] = fixed_pipeline
        __props__.__dict__["issue_due"] = issue_due
        __props__.__dict__["level"] = level
        __props__.__dict__["merge_merge_request"] = merge_merge_request
        __props__.__dict__["merge_when_pipeline_succeeds"] = merge_when_pipeline_succeeds
        __props__.__dict__["moved_project"] = moved_project
        __props__.__dict__["new_issue"] = new_issue
        __props__.__dict__["new_merge_request"] = new_merge_request
        __props__.__dict__["new_note"] = new_note
        __props__.__dict__["project"] = project
        __props__.__dict__["push_to_merge_request"] = push_to_merge_request
        __props__.__dict__["reassign_issue"] = reassign_issue
        __props__.__dict__["reassign_merge_request"] = reassign_merge_request
        __props__.__dict__["reopen_issue"] = reopen_issue
        __props__.__dict__["reopen_merge_request"] = reopen_merge_request
        __props__.__dict__["success_pipeline"] = success_pipeline
        return ProjectLevelNotifications(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="closeIssue")
    def close_issue(self) -> pulumi.Output[bool]:
        """
        Enable notifications for closed issues. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "close_issue")

    @property
    @pulumi.getter(name="closeMergeRequest")
    def close_merge_request(self) -> pulumi.Output[bool]:
        """
        Enable notifications for closed merge requests. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "close_merge_request")

    @property
    @pulumi.getter(name="failedPipeline")
    def failed_pipeline(self) -> pulumi.Output[bool]:
        """
        Enable notifications for failed pipelines. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "failed_pipeline")

    @property
    @pulumi.getter(name="fixedPipeline")
    def fixed_pipeline(self) -> pulumi.Output[bool]:
        """
        Enable notifications for fixed pipelines. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "fixed_pipeline")

    @property
    @pulumi.getter(name="issueDue")
    def issue_due(self) -> pulumi.Output[bool]:
        """
        Enable notifications for due issues. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "issue_due")

    @property
    @pulumi.getter
    def level(self) -> pulumi.Output[str]:
        """
        The level of the notification. Valid values are: `disabled`, `participating`, `watch`, `global`, `mention`, `custom`.
        """
        return pulumi.get(self, "level")

    @property
    @pulumi.getter(name="mergeMergeRequest")
    def merge_merge_request(self) -> pulumi.Output[bool]:
        """
        Enable notifications for merged merge requests. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "merge_merge_request")

    @property
    @pulumi.getter(name="mergeWhenPipelineSucceeds")
    def merge_when_pipeline_succeeds(self) -> pulumi.Output[bool]:
        """
        Enable notifications for merged merge requests when the pipeline succeeds. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "merge_when_pipeline_succeeds")

    @property
    @pulumi.getter(name="movedProject")
    def moved_project(self) -> pulumi.Output[bool]:
        """
        Enable notifications for moved projects. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "moved_project")

    @property
    @pulumi.getter(name="newIssue")
    def new_issue(self) -> pulumi.Output[bool]:
        """
        Enable notifications for new issues. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "new_issue")

    @property
    @pulumi.getter(name="newMergeRequest")
    def new_merge_request(self) -> pulumi.Output[bool]:
        """
        Enable notifications for new merge requests. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "new_merge_request")

    @property
    @pulumi.getter(name="newNote")
    def new_note(self) -> pulumi.Output[bool]:
        """
        Enable notifications for new notes on merge requests. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "new_note")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[str]:
        """
        The ID or URL-encoded path of a project where notifications will be configured.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter(name="pushToMergeRequest")
    def push_to_merge_request(self) -> pulumi.Output[bool]:
        """
        Enable notifications for push to merge request branches. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "push_to_merge_request")

    @property
    @pulumi.getter(name="reassignIssue")
    def reassign_issue(self) -> pulumi.Output[bool]:
        """
        Enable notifications for issue reassignments. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "reassign_issue")

    @property
    @pulumi.getter(name="reassignMergeRequest")
    def reassign_merge_request(self) -> pulumi.Output[bool]:
        """
        Enable notifications for merge request reassignments. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "reassign_merge_request")

    @property
    @pulumi.getter(name="reopenIssue")
    def reopen_issue(self) -> pulumi.Output[bool]:
        """
        Enable notifications for reopened issues. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "reopen_issue")

    @property
    @pulumi.getter(name="reopenMergeRequest")
    def reopen_merge_request(self) -> pulumi.Output[bool]:
        """
        Enable notifications for reopened merge requests. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "reopen_merge_request")

    @property
    @pulumi.getter(name="successPipeline")
    def success_pipeline(self) -> pulumi.Output[bool]:
        """
        Enable notifications for successful pipelines. Can only be used when `level` is `custom`.
        """
        return pulumi.get(self, "success_pipeline")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ProjectShareGroupArgs', 'ProjectShareGroup']

@pulumi.input_type
class ProjectShareGroupArgs:
    def __init__(__self__, *,
                 group_id: pulumi.Input[int],
                 project: pulumi.Input[str],
                 access_level: Optional[pulumi.Input[str]] = None,
                 group_access: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a ProjectShareGroup resource.
        :param pulumi.Input[int] group_id: The id of the group.
        :param pulumi.Input[str] project: The ID or URL-encoded path of the project.
        :param pulumi.Input[str] access_level: The access level to grant the group for the project. Valid values are: `no one`, `minimal`, `guest`, `reporter`, `developer`, `maintainer`, `owner`
        :param pulumi.Input[str] group_access: The access level to grant the group for the project. Valid values are: `no one`, `minimal`, `guest`, `reporter`, `developer`, `maintainer`, `owner`
        """
        pulumi.set(__self__, "group_id", group_id)
        pulumi.set(__self__, "project", project)
        if access_level is not None:
            warnings.warn("""Use `group_access` instead of the `access_level` attribute.""", DeprecationWarning)
            pulumi.log.warn("""access_level is deprecated: Use `group_access` instead of the `access_level` attribute.""")
        if access_level is not None:
            pulumi.set(__self__, "access_level", access_level)
        if group_access is not None:
            pulumi.set(__self__, "group_access", group_access)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Input[int]:
        """
        The id of the group.
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: pulumi.Input[int]):
        pulumi.set(self, "group_id", value)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Input[str]:
        """
        The ID or URL-encoded path of the project.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[str]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter(name="accessLevel")
    @_utilities.deprecated("""Use `group_access` instead of the `access_level` attribute.""")
    def access_level(self) -> Optional[pulumi.Input[str]]:
        """
        The access level to grant the group for the project. Valid values are: `no one`, `minimal`, `guest`, `reporter`, `developer`, `maintainer`, `owner`
        """
        return pulumi.get(self, "access_level")

    @access_level.setter
    def access_level(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "access_level", value)

    @property
    @pulumi.getter(name="groupAccess")
    def group_access(self) -> Optional[pulumi.Input[str]]:
        """
        The access level to grant the group for the project. Valid values are: `no one`, `minimal`, `guest`, `reporter`, `developer`, `maintainer`, `owner`
        """
        return pulumi.get(self, "group_access")

    @group_access.setter
    def group_access(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group_access", value)


@pulumi.input_type
class _ProjectShareGroupState:
    def __init__(__self__, *,
                 access_level: Optional[pulumi.Input[str]] = None,
                 group_access: Optional[pulumi.Input[str]] = None,
                 group_id: Optional[pulumi.Input[int]] = None,
                 project: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ProjectShareGroup resources.
        :param pulumi.Input[str] access_level: The access level to grant the group for the project. Valid values are: `no one`, `minimal`, `guest`, `reporter`, `developer`, `maintainer`, `owner`
        :param pulumi.Input[str] group_access: The access level to grant the group for the project. Valid values are: `no one`, `minimal`, `guest`, `reporter`, `developer`, `maintainer`, `owner`
        :param pulumi.Input[int] group_id: The id of the group.
        :param pulumi.Input[str] project: The ID or URL-encoded path of the project.
        """
        if access_level is not None:
            warnings.warn("""Use `group_access` instead of the `access_level` attribute.""", DeprecationWarning)
            pulumi.log.warn("""access_level is deprecated: Use `group_access` instead of the `access_level` attribute.""")
        if access_level is not None:
            pulumi.set(__self__, "access_level", access_level)
        if group_access is not None:
            pulumi.set(__self__, "group_access", group_access)
        if group_id is not None:
            pulumi.set(__self__, "group_id", group_id)
        if project is not None:
            pulumi.set(__self__, "project", project)

    @property
    @pulumi.getter(name="accessLevel")
    @_utilities.deprecated("""Use `group_access` instead of the `access_level` attribute.""")
    def access_level(self) -> Optional[pulumi.Input[str]]:
        """
        The access level to grant the group for the project. Valid values are: `no one`, `minimal`, `guest`, `reporter`, `developer`, `maintainer`, `owner`
        """
        return pulumi.get(self, "access_level")

    @access_level.setter
    def access_level(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "access_level", value)

    @property
    @pulumi.getter(name="groupAccess")
    def group_access(self) -> Optional[pulumi.Input[str]]:
        """
        The access level to grant the group for the project. Valid values are: `no one`, `minimal`, `guest`, `reporter`, `developer`, `maintainer`, `owner`
        """
        return pulumi.get(self, "group_access")

    @group_access.setter
    def group_access(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group_access", value)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> Optional[pulumi.Input[int]]:
        """
        The id of the group.
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "group_id", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        The ID or URL-encoded path of the project.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)


class ProjectShareGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_level: Optional[pulumi.Input[str]] = None,
                 group_access: Optional[pulumi.Input[str]] = None,
                 group_id: Optional[pulumi.Input[int]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        The `ProjectShareGroup` resource allows to manage the lifecycle of project shared with a group.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/projects/#share-project-with-group)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        test = gitlab.ProjectShareGroup("test",
            project="12345",
            group_id=1337,
            group_access="guest")
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_project_share_group`. For example:

        terraform

        import {

          to = gitlab_project_share_group.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        GitLab project group shares can be imported using an id made up of `projectid:groupid`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectShareGroup:ProjectShareGroup test 12345:1337
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] access_level: The access level to grant the group for the project. Valid values are: `no one`, `minimal`, `guest`, `reporter`, `developer`, `maintainer`, `owner`
        :param pulumi.Input[str] group_access: The access level to grant the group for the project. Valid values are: `no one`, `minimal`, `guest`, `reporter`, `developer`, `maintainer`, `owner`
        :param pulumi.Input[int] group_id: The id of the group.
        :param pulumi.Input[str] project: The ID or URL-encoded path of the project.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectShareGroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `ProjectShareGroup` resource allows to manage the lifecycle of project shared with a group.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/projects/#share-project-with-group)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        test = gitlab.ProjectShareGroup("test",
            project="12345",
            group_id=1337,
            group_access="guest")
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_project_share_group`. For example:

        terraform

        import {

          to = gitlab_project_share_group.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        GitLab project group shares can be imported using an id made up of `projectid:groupid`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectShareGroup:ProjectShareGroup test 12345:1337
        ```

        :param str resource_name: The name of the resource.
        :param ProjectShareGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectShareGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_level: Optional[pulumi.Input[str]] = None,
                 group_access: Optional[pulumi.Input[str]] = None,
                 group_id: Optional[pulumi.Input[int]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectShareGroupArgs.__new__(ProjectShareGroupArgs)

            __props__.__dict__["access_level"] = access_level
            __props__.__dict__["group_access"] = group_access
            if group_id is None and not opts.urn:
                raise TypeError("Missing required property 'group_id'")
            __props__.__dict__["group_id"] = group_id
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
        super(ProjectShareGroup, __self__).__init__(
            'gitlab:index/projectShareGroup:ProjectShareGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_level: Optional[pulumi.Input[str]] = None,
            group_access: Optional[pulumi.Input[str]] = None,
            group_id: Optional[pulumi.Input[int]] = None,
            project: Optional[pulumi.Input[str]] = None) -> 'ProjectShareGroup':
        """
        Get an existing ProjectShareGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] access_level: The access level to grant the group for the project. Valid values are: `no one`, `minimal`, `guest`, `reporter`, `developer`, `maintainer`, `owner`
        :param pulumi.Input[str] group_access: The access level to grant the group for the project. Valid values are: `no one`, `minimal`, `guest`, `reporter`, `developer`, `maintainer`, `owner`
        :param pulumi.Input[int] group_id: The id of the group.
        :param pulumi.Input[str] project: The ID or URL-encoded path of the project.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectShareGroupState.__new__(_ProjectShareGroupState)

        __props__.__dict__["access_level"] = access_level
        __props__.__dict__["group_access"] = group_access
        __props__.__dict__["group_id"] = group_id
        __props__.__dict__["project"] = project
        return ProjectShareGroup(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accessLevel")
    @_utilities.deprecated("""Use `group_access` instead of the `access_level` attribute.""")
    def access_level(self) -> pulumi.Output[Optional[str]]:
        """
        The access level to grant the group for the project. Valid values are: `no one`, `minimal`, `guest`, `reporter`, `developer`, `maintainer`, `owner`
        """
        return pulumi.get(self, "access_level")

    @property
    @pulumi.getter(name="groupAccess")
    def group_access(self) -> pulumi.Output[Optional[str]]:
        """
        The access level to grant the group for the project. Valid values are: `no one`, `minimal`, `guest`, `reporter`, `developer`, `maintainer`, `owner`
        """
        return pulumi.get(self, "group_access")

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Output[int]:
        """
        The id of the group.
        """
        return pulumi.get(self, "group_id")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[str]:
        """
        The ID or URL-encoded path of the project.
        """
        return pulumi.get(self, "project")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ServiceEmailsOnPushArgs', 'ServiceEmailsOnPush']

@pulumi.input_type
class ServiceEmailsOnPushArgs:
    def __init__(__self__, *,
                 project: pulumi.Input[str],
                 recipients: pulumi.Input[str],
                 branches_to_be_notified: Optional[pulumi.Input[str]] = None,
                 disable_diffs: Optional[pulumi.Input[bool]] = None,
                 push_events: Optional[pulumi.Input[bool]] = None,
                 send_from_committer_email: Optional[pulumi.Input[bool]] = None,
                 tag_push_events: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a ServiceEmailsOnPush resource.
        :param pulumi.Input[str] project: ID or full-path of the project you want to activate integration on.
        :param pulumi.Input[str] recipients: Emails separated by whitespace.
        :param pulumi.Input[str] branches_to_be_notified: Branches to send notifications for. Valid options are `all`, `default`, `protected`, `default_and_protected`. Notifications are always fired for tag pushes.
        :param pulumi.Input[bool] disable_diffs: Disable code diffs.
        :param pulumi.Input[bool] push_events: Enable notifications for push events.
        :param pulumi.Input[bool] send_from_committer_email: Send from committer.
        :param pulumi.Input[bool] tag_push_events: Enable notifications for tag push events.
        """
        pulumi.set(__self__, "project", project)
        pulumi.set(__self__, "recipients", recipients)
        if branches_to_be_notified is not None:
            pulumi.set(__self__, "branches_to_be_notified", branches_to_be_notified)
        if disable_diffs is not None:
            pulumi.set(__self__, "disable_diffs", disable_diffs)
        if push_events is not None:
            pulumi.set(__self__, "push_events", push_events)
        if send_from_committer_email is not None:
            pulumi.set(__self__, "send_from_committer_email", send_from_committer_email)
        if tag_push_events is not None:
            pulumi.set(__self__, "tag_push_events", tag_push_events)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Input[str]:
        """
        ID or full-path of the project you want to activate integration on.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[str]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def recipients(self) -> pulumi.Input[str]:
        """
        Emails separated by whitespace.
        """
        return pulumi.get(self, "recipients")

    @recipients.setter
    def recipients(self, value: pulumi.Input[str]):
        pulumi.set(self, "recipients", value)

    @property
    @pulumi.getter(name="branchesToBeNotified")
    def branches_to_be_notified(self) -> Optional[pulumi.Input[str]]:
        """
        Branches to send notifications for. Valid options are `all`, `default`, `protected`, `default_and_protected`. Notifications are always fired for tag pushes.
        """
        return pulumi.get(self, "branches_to_be_notified")

    @branches_to_be_notified.setter
    def branches_to_be_notified(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "branches_to_be_notified", value)

    @property
    @pulumi.getter(name="disableDiffs")
    def disable_diffs(self) -> Optional[pulumi.Input[bool]]:
        """
        Disable code diffs.
        """
        return pulumi.get(self, "disable_diffs")

    @disable_diffs.setter
    def disable_diffs(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "disable_diffs", value)

    @property
    @pulumi.getter(name="pushEvents")
    def push_events(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for push events.
        """
        return pulumi.get(self, "push_events")

    @push_events.setter
    def push_events(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "push_events", value)

    @property
    @pulumi.getter(name="sendFromCommitterEmail")
    def send_from_committer_email(self) -> Optional[pulumi.Input[bool]]:
        """
        Send from committer.
        """
        return pulumi.get(self, "send_from_committer_email")

    @send_from_committer_email.setter
    def send_from_committer_email(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "send_from_committer_email", value)

    @property
    @pulumi.getter(name="tagPushEvents")
    def tag_push_events(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for tag push events.
        """
        return pulumi.get(self, "tag_push_events")

    @tag_push_events.setter
    def tag_push_events(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "tag_push_events", value)


@pulumi.input_type
class _ServiceEmailsOnPushState:
    def __init__(__self__, *,
                 active: Optional[pulumi.Input[bool]] = None,
                 branches_to_be_notified: Optional[pulumi.Input[str]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 disable_diffs: Optional[pulumi.Input[bool]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 push_events: Optional[pulumi.Input[bool]] = None,
                 recipients: Optional[pulumi.Input[str]] = None,
                 send_from_committer_email: Optional[pulumi.Input[bool]] = None,
                 slug: Optional[pulumi.Input[str]] = None,
                 tag_push_events: Optional[pulumi.Input[bool]] = None,
                 title: Optional[pulumi.Input[str]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ServiceEmailsOnPush resources.
        :param pulumi.Input[bool] active: Whether the integration is active.
        :param pulumi.Input[str] branches_to_be_notified: Branches to send notifications for. Valid options are `all`, `default`, `protected`, `default_and_protected`. Notifications are always fired for tag pushes.
        :param pulumi.Input[str] created_at: The ISO8601 date/time that this integration was activated at in UTC.
        :param pulumi.Input[bool] disable_diffs: Disable code diffs.
        :param pulumi.Input[str] project: ID or full-path of the project you want to activate integration on.
        :param pulumi.Input[bool] push_events: Enable notifications for push events.
        :param pulumi.Input[str] recipients: Emails separated by whitespace.
        :param pulumi.Input[bool] send_from_committer_email: Send from committer.
        :param pulumi.Input[str] slug: The name of the integration in lowercase, shortened to 63 bytes, and with everything except 0-9 and a-z replaced with -. No leading / trailing -. Use in URLs, host names and domain names.
        :param pulumi.Input[bool] tag_push_events: Enable notifications for tag push events.
        :param pulumi.Input[str] title: Title of the integration.
        :param pulumi.Input[str] updated_at: The ISO8601 date/time that this integration was last updated at in UTC.
        """
        if active is not None:
            pulumi.set(__self__, "active", active)
        if branches_to_be_notified is not None:
            pulumi.set(__self__, "branches_to_be_notified", branches_to_be_notified)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if disable_diffs is not None:
            pulumi.set(__self__, "disable_diffs", disable_diffs)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if push_events is not None:
            pulumi.set(__self__, "push_events", push_events)
        if recipients is not None:
            pulumi.set(__self__, "recipients", recipients)
        if send_from_committer_email is not None:
            pulumi.set(__self__, "send_from_committer_email", send_from_committer_email)
        if slug is not None:
            pulumi.set(__self__, "slug", slug)
        if tag_push_events is not None:
            pulumi.set(__self__, "tag_push_events", tag_push_events)
        if title is not None:
            pulumi.set(__self__, "title", title)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter
    def active(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the integration is active.
        """
        return pulumi.get(self, "active")

    @active.setter
    def active(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "active", value)

    @property
    @pulumi.getter(name="branchesToBeNotified")
    def branches_to_be_notified(self) -> Optional[pulumi.Input[str]]:
        """
        Branches to send notifications for. Valid options are `all`, `default`, `protected`, `default_and_protected`. Notifications are always fired for tag pushes.
        """
        return pulumi.get(self, "branches_to_be_notified")

    @branches_to_be_notified.setter
    def branches_to_be_notified(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "branches_to_be_notified", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        The ISO8601 date/time that this integration was activated at in UTC.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter(name="disableDiffs")
    def disable_diffs(self) -> Optional[pulumi.Input[bool]]:
        """
        Disable code diffs.
        """
        return pulumi.get(self, "disable_diffs")

    @disable_diffs.setter
    def disable_diffs(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "disable_diffs", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        ID or full-path of the project you want to activate integration on.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter(name="pushEvents")
    def push_events(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for push events.
        """
        return pulumi.get(self, "push_events")

    @push_events.setter
    def push_events(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "push_events", value)

    @property
    @pulumi.getter
    def recipients(self) -> Optional[pulumi.Input[str]]:
        """
        Emails separated by whitespace.
        """
        return pulumi.get(self, "recipients")

    @recipients.setter
    def recipients(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "recipients", value)

    @property
    @pulumi.getter(name="sendFromCommitterEmail")
    def send_from_committer_email(self) -> Optional[pulumi.Input[bool]]:
        """
        Send from committer.
        """
        return pulumi.get(self, "send_from_committer_email")

    @send_from_committer_email.setter
    def send_from_committer_email(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "send_from_committer_email", value)

    @property
    @pulumi.getter
    def slug(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the integration in lowercase, shortened to 63 bytes, and with everything except 0-9 and a-z replaced with -. No leading / trailing -. Use in URLs, host names and domain names.
        """
        return pulumi.get(self, "slug")

    @slug.setter
    def slug(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "slug", value)

    @property
    @pulumi.getter(name="tagPushEvents")
    def tag_push_events(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for tag push events.
        """
        return pulumi.get(self, "tag_push_events")

    @tag_push_events.setter
    def tag_push_events(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "tag_push_events", value)

    @property
    @pulumi.getter
    def title(self) -> Optional[pulumi.Input[str]]:
        """
        Title of the integration.
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "title", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[str]]:
        """
        The ISO8601 date/time that this integration was last updated at in UTC.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_at", value)


class ServiceEmailsOnPush(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 branches_to_be_notified: Optional[pulumi.Input[str]] = None,
                 disable_diffs: Optional[pulumi.Input[bool]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 push_events: Optional[pulumi.Input[bool]] = None,
                 recipients: Optional[pulumi.Input[str]] = None,
                 send_from_committer_email: Optional[pulumi.Input[bool]] = None,
                 tag_push_events: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        """
        The `ServiceEmailsOnPush` resource allows to manage the lifecycle of a project integration with Emails on Push Service.

        > This resource is deprecated. Please use `IntegrationEmailsOnPush` instead!

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/integrations/#emails-on-push)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        awesome_project = gitlab.Project("awesome_project",
            name="awesome_project",
            description="My awesome project.",
            visibility_level="public")
        emails = gitlab.ServiceEmailsOnPush("emails",
            project=awesome_project.id,
            recipients="myrecipient@example.com myotherrecipient@example.com")
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_service_emails_on_push`. For example:

        terraform

        import {

          to = gitlab_service_emails_on_push.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        You can import a gitlab_service_emails_on_push state using the project ID, e.g.

        ```sh
        $ pulumi import gitlab:index/serviceEmailsOnPush:ServiceEmailsOnPush emails 1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] branches_to_be_notified: Branches to send notifications for. Valid options are `all`, `default`, `protected`, `default_and_protected`. Notifications are always fired for tag pushes.
        :param pulumi.Input[bool] disable_diffs: Disable code diffs.
        :param pulumi.Input[str] project: ID or full-path of the project you want to activate integration on.
        :param pulumi.Input[bool] push_events: Enable notifications for push events.
        :param pulumi.Input[str] recipients: Emails separated by whitespace.
        :param pulumi.Input[bool] send_from_committer_email: Send from committer.
        :param pulumi.Input[bool] tag_push_events: Enable notifications for tag push events.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ServiceEmailsOnPushArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `ServiceEmailsOnPush` resource allows to manage the lifecycle of a project integration with Emails on Push Service.

        > This resource is deprecated. Please use `IntegrationEmailsOnPush` instead!

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/integrations/#emails-on-push)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        awesome_project = gitlab.Project("awesome_project",
            name="awesome_project",
            description="My awesome project.",
            visibility_level="public")
        emails = gitlab.ServiceEmailsOnPush("emails",
            project=awesome_project.id,
            recipients="myrecipient@example.com myotherrecipient@example.com")
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_service_emails_on_push`. For example:

        terraform

        import {

          to = gitlab_service_emails_on_push.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        You can import a gitlab_service_emails_on_push state using the project ID, e.g.

        ```sh
        $ pulumi import gitlab:index/serviceEmailsOnPush:ServiceEmailsOnPush emails 1
        ```

        :param str resource_name: The name of the resource.
        :param ServiceEmailsOnPushArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ServiceEmailsOnPushArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 branches_to_be_notified: Optional[pulumi.Input[str]] = None,
                 disable_diffs: Optional[pulumi.Input[bool]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 push_events: Optional[pulumi.Input[bool]] = None,
                 recipients: Optional[pulumi.Input[str]] = None,
                 send_from_committer_email: Optional[pulumi.Input[bool]] = None,
                 tag_push_events: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ServiceEmailsOnPushArgs.__new__(ServiceEmailsOnPushArgs)

            __props__.__dict__["branches_to_be_notified"] = branches_to_be_notified
            __props__.__dict__["disable_diffs"] = disable_diffs
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            __props__.__dict__["push_events"] = push_events
            if recipients is None and not opts.urn:
                raise TypeError("Missing required property 'recipients'")
            __props__.__dict__["recipients"] = recipients
            __props__.__dict__["send_from_committer_email"] = send_from_committer_email
            __props__.__dict__["tag_push_events"] = tag_push_events
            __props__.__dict__["active"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["slug"] = None
            __props__.__dict__["title"] = None
            __props__.__dict__["updated_at"] = None
        super(ServiceEmailsOnPush, __self__).__init__(
            'gitlab:index/serviceEmailsOnPush:ServiceEmailsOnPush',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            active: Optional[pulumi.Input[bool]] = None,
            branches_to_be_notified: Optional[pulumi.Input[str]] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            disable_diffs: Optional[pulumi.Input[bool]] = None,
            project: Optional[pulumi.Input[str]] = None,
            push_events: Optional[pulumi.Input[bool]] = None,
            recipients: Optional[pulumi.Input[str]] = None,
            send_from_committer_email: Optional[pulumi.Input[bool]] = None,
            slug: Optional[pulumi.Input[str]] = None,
            tag_push_events: Optional[pulumi.Input[bool]] = None,
            title: Optional[pulumi.Input[str]] = None,
            updated_at: Optional[pulumi.Input[str]] = None) -> 'ServiceEmailsOnPush':
        """
        Get an existing ServiceEmailsOnPush resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] active: Whether the integration is active.
        :param pulumi.Input[str] branches_to_be_notified: Branches to send notifications for. Valid options are `all`, `default`, `protected`, `default_and_protected`. Notifications are always fired for tag pushes.
        :param pulumi.Input[str] created_at: The ISO8601 date/time that this integration was activated at in UTC.
        :param pulumi.Input[bool] disable_diffs: Disable code diffs.
        :param pulumi.Input[str] project: ID or full-path of the project you want to activate integration on.
        :param pulumi.Input[bool] push_events: Enable notifications for push events.
        :param pulumi.Input[str] recipients: Emails separated by whitespace.
        :param pulumi.Input[bool] send_from_committer_email: Send from committer.
        :param pulumi.Input[str] slug: The name of the integration in lowercase, shortened to 63 bytes, and with everything except 0-9 and a-z replaced with -. No leading / trailing -. Use in URLs, host names and domain names.
        :param pulumi.Input[bool] tag_push_events: Enable notifications for tag push events.
        :param pulumi.Input[str] title: Title of the integration.
        :param pulumi.Input[str] updated_at: The ISO8601 date/time that this integration was last updated at in UTC.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ServiceEmailsOnPushState.__new__(_ServiceEmailsOnPushState)

        __props__.__dict__["active"] = active
        __props__.__dict__["branches_to_be_notified"] = branches_to_be_notified
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["disable_diffs"] = disable_diffs
        __props__.__dict__["project"] = project
        __props__.__dict__["push_events"] = push_events
        __props__.__dict__["recipients"] = recipients
        __props__.__dict__["send_from_committer_email"] = send_from_committer_email
        __props__.__dict__["slug"] = slug
        __props__.__dict__["tag_push_events"] = tag_push_events
        __props__.__dict__["title"] = title
        __props__.__dict__["updated_at"] = updated_at
        return ServiceEmailsOnPush(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def active(self) -> pulumi.Output[bool]:
        """
        Whether the integration is active.
        """
        return pulumi.get(self, "active")

    @property
    @pulumi.getter(name="branchesToBeNotified")
    def branches_to_be_notified(self) -> pulumi.Output[Optional[str]]:
        """
        Branches to send notifications for. Valid options are `all`, `default`, `protected`, `default_and_protected`. Notifications are always fired for tag pushes.
        """
        return pulumi.get(self, "branches_to_be_notified")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        """
        The ISO8601 date/time that this integration was activated at in UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="disableDiffs")
    def disable_diffs(self) -> pulumi.Output[Optional[bool]]:
        """
        Disable code diffs.
        """
        return pulumi.get(self, "disable_diffs")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[str]:
        """
        ID or full-path of the project you want to activate integration on.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter(name="pushEvents")
    def push_events(self) -> pulumi.Output[Optional[bool]]:
        """
        Enable notifications for push events.
        """
        return pulumi.get(self, "push_events")

    @property
    @pulumi.getter
    def recipients(self) -> pulumi.Output[str]:
        """
        Emails separated by whitespace.
        """
        return pulumi.get(self, "recipients")

    @property
    @pulumi.getter(name="sendFromCommitterEmail")
    def send_from_committer_email(self) -> pulumi.Output[Optional[bool]]:
        """
        Send from committer.
        """
        return pulumi.get(self, "send_from_committer_email")

    @property
    @pulumi.getter
    def slug(self) -> pulumi.Output[str]:
        """
        The name of the integration in lowercase, shortened to 63 bytes, and with everything except 0-9 and a-z replaced with -. No leading / trailing -. Use in URLs, host names and domain names.
        """
        return pulumi.get(self, "slug")

    @property
    @pulumi.getter(name="tagPushEvents")
    def tag_push_events(self) -> pulumi.Output[Optional[bool]]:
        """
        Enable notifications for tag push events.
        """
        return pulumi.get(self, "tag_push_events")

    @property
    @pulumi.getter
    def title(self) -> pulumi.Output[str]:
        """
        Title of the integration.
        """
        return pulumi.get(self, "title")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[str]:
        """
        The ISO8601 date/time that this integration was last updated at in UTC.
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetInstanceServiceAccountResult',
    'AwaitableGetInstanceServiceAccountResult',
    'get_instance_service_account',
    'get_instance_service_account_output',
]

@pulumi.output_type
class GetInstanceServiceAccountResult:
    """
    A collection of values returned by getInstanceServiceAccount.
    """
    def __init__(__self__, id=None, name=None, service_account_id=None, username=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if service_account_id and not isinstance(service_account_id, str):
            raise TypeError("Expected argument 'service_account_id' to be a str")
        pulumi.set(__self__, "service_account_id", service_account_id)
        if username and not isinstance(username, str):
            raise TypeError("Expected argument 'username' to be a str")
        pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the user.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="serviceAccountId")
    def service_account_id(self) -> str:
        """
        The service account id.
        """
        return pulumi.get(self, "service_account_id")

    @property
    @pulumi.getter
    def username(self) -> str:
        """
        The username of the user.
        """
        return pulumi.get(self, "username")


class AwaitableGetInstanceServiceAccountResult(GetInstanceServiceAccountResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstanceServiceAccountResult(
            id=self.id,
            name=self.name,
            service_account_id=self.service_account_id,
            username=self.username)


def get_instance_service_account(service_account_id: Optional[str] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInstanceServiceAccountResult:
    """
    The `InstanceServiceAccount` data source retrieves information about a gitlab service account.

    > In order for a user to create a user account, they must have admin privileges at the instance level. This makes this feature unavailable on `gitlab.com`

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/user_service_accounts/)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    example = gitlab.get_instance_service_account(service_account_id="123")
    ```


    :param str service_account_id: The service account id.
    """
    __args__ = dict()
    __args__['serviceAccountId'] = service_account_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getInstanceServiceAccount:getInstanceServiceAccount', __args__, opts=opts, typ=GetInstanceServiceAccountResult).value

    return AwaitableGetInstanceServiceAccountResult(
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        service_account_id=pulumi.get(__ret__, 'service_account_id'),
        username=pulumi.get(__ret__, 'username'))
def get_instance_service_account_output(service_account_id: Optional[pulumi.Input[str]] = None,
                                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetInstanceServiceAccountResult]:
    """
    The `InstanceServiceAccount` data source retrieves information about a gitlab service account.

    > In order for a user to create a user account, they must have admin privileges at the instance level. This makes this feature unavailable on `gitlab.com`

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/user_service_accounts/)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    example = gitlab.get_instance_service_account(service_account_id="123")
    ```


    :param str service_account_id: The service account id.
    """
    __args__ = dict()
    __args__['serviceAccountId'] = service_account_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getInstanceServiceAccount:getInstanceServiceAccount', __args__, opts=opts, typ=GetInstanceServiceAccountResult)
    return __ret__.apply(lambda __response__: GetInstanceServiceAccountResult(
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        service_account_id=pulumi.get(__response__, 'service_account_id'),
        username=pulumi.get(__response__, 'username')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['DeployTokenArgs', 'DeployToken']

@pulumi.input_type
class DeployTokenArgs:
    def __init__(__self__, *,
                 scopes: pulumi.Input[Sequence[pulumi.Input[str]]],
                 expires_at: Optional[pulumi.Input[str]] = None,
                 group: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a DeployToken resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] scopes: Valid values: `read_repository`, `read_registry`, `read_package_registry`, `write_registry`, `write_package_registry`.
        :param pulumi.Input[str] expires_at: Time the token will expire it, RFC3339 format. Will not expire per default.
        :param pulumi.Input[str] group: The name or id of the group to add the deploy token to.
        :param pulumi.Input[str] name: A name to describe the deploy token with.
        :param pulumi.Input[str] project: The name or id of the project to add the deploy token to.
        :param pulumi.Input[str] username: A username for the deploy token. Default is `gitlab+deploy-token-{n}`.
        """
        pulumi.set(__self__, "scopes", scopes)
        if expires_at is not None:
            pulumi.set(__self__, "expires_at", expires_at)
        if group is not None:
            pulumi.set(__self__, "group", group)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter
    def scopes(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        Valid values: `read_repository`, `read_registry`, `read_package_registry`, `write_registry`, `write_package_registry`.
        """
        return pulumi.get(self, "scopes")

    @scopes.setter
    def scopes(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "scopes", value)

    @property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> Optional[pulumi.Input[str]]:
        """
        Time the token will expire it, RFC3339 format. Will not expire per default.
        """
        return pulumi.get(self, "expires_at")

    @expires_at.setter
    def expires_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "expires_at", value)

    @property
    @pulumi.getter
    def group(self) -> Optional[pulumi.Input[str]]:
        """
        The name or id of the group to add the deploy token to.
        """
        return pulumi.get(self, "group")

    @group.setter
    def group(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A name to describe the deploy token with.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        The name or id of the project to add the deploy token to.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[str]]:
        """
        A username for the deploy token. Default is `gitlab+deploy-token-{n}`.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "username", value)


@pulumi.input_type
class _DeployTokenState:
    def __init__(__self__, *,
                 deploy_token_id: Optional[pulumi.Input[int]] = None,
                 expires_at: Optional[pulumi.Input[str]] = None,
                 group: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 scopes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 token: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering DeployToken resources.
        :param pulumi.Input[int] deploy_token_id: The id of the deploy token.
        :param pulumi.Input[str] expires_at: Time the token will expire it, RFC3339 format. Will not expire per default.
        :param pulumi.Input[str] group: The name or id of the group to add the deploy token to.
        :param pulumi.Input[str] name: A name to describe the deploy token with.
        :param pulumi.Input[str] project: The name or id of the project to add the deploy token to.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] scopes: Valid values: `read_repository`, `read_registry`, `read_package_registry`, `write_registry`, `write_package_registry`.
        :param pulumi.Input[str] token: The secret token. This is only populated when creating a new deploy token. **Note**: The token is not available for imported resources.
        :param pulumi.Input[str] username: A username for the deploy token. Default is `gitlab+deploy-token-{n}`.
        """
        if deploy_token_id is not None:
            pulumi.set(__self__, "deploy_token_id", deploy_token_id)
        if expires_at is not None:
            pulumi.set(__self__, "expires_at", expires_at)
        if group is not None:
            pulumi.set(__self__, "group", group)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if scopes is not None:
            pulumi.set(__self__, "scopes", scopes)
        if token is not None:
            pulumi.set(__self__, "token", token)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter(name="deployTokenId")
    def deploy_token_id(self) -> Optional[pulumi.Input[int]]:
        """
        The id of the deploy token.
        """
        return pulumi.get(self, "deploy_token_id")

    @deploy_token_id.setter
    def deploy_token_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "deploy_token_id", value)

    @property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> Optional[pulumi.Input[str]]:
        """
        Time the token will expire it, RFC3339 format. Will not expire per default.
        """
        return pulumi.get(self, "expires_at")

    @expires_at.setter
    def expires_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "expires_at", value)

    @property
    @pulumi.getter
    def group(self) -> Optional[pulumi.Input[str]]:
        """
        The name or id of the group to add the deploy token to.
        """
        return pulumi.get(self, "group")

    @group.setter
    def group(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A name to describe the deploy token with.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        The name or id of the project to add the deploy token to.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Valid values: `read_repository`, `read_registry`, `read_package_registry`, `write_registry`, `write_package_registry`.
        """
        return pulumi.get(self, "scopes")

    @scopes.setter
    def scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "scopes", value)

    @property
    @pulumi.getter
    def token(self) -> Optional[pulumi.Input[str]]:
        """
        The secret token. This is only populated when creating a new deploy token. **Note**: The token is not available for imported resources.
        """
        return pulumi.get(self, "token")

    @token.setter
    def token(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "token", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[str]]:
        """
        A username for the deploy token. Default is `gitlab+deploy-token-{n}`.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "username", value)


class DeployToken(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 expires_at: Optional[pulumi.Input[str]] = None,
                 group: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 scopes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 username: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        The `DeployToken` resource allows to manage the lifecycle of group and project deploy tokens.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/deploy_tokens/)

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_deploy_token`. For example:

        terraform

        import {

          to = gitlab_deploy_token.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        GitLab deploy tokens can be imported using an id made up of `{type}:{type_id}:{deploy_token_id}`, where type is one of: project, group.

        ```sh
        $ pulumi import gitlab:index/deployToken:DeployToken group_token group:1:3
        ```

        ```sh
        $ pulumi import gitlab:index/deployToken:DeployToken project_token project:1:4
        ```

        Note: the `token` resource attribute is not available for imported resources as this information cannot be read from the GitLab API.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] expires_at: Time the token will expire it, RFC3339 format. Will not expire per default.
        :param pulumi.Input[str] group: The name or id of the group to add the deploy token to.
        :param pulumi.Input[str] name: A name to describe the deploy token with.
        :param pulumi.Input[str] project: The name or id of the project to add the deploy token to.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] scopes: Valid values: `read_repository`, `read_registry`, `read_package_registry`, `write_registry`, `write_package_registry`.
        :param pulumi.Input[str] username: A username for the deploy token. Default is `gitlab+deploy-token-{n}`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DeployTokenArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `DeployToken` resource allows to manage the lifecycle of group and project deploy tokens.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/deploy_tokens/)

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_deploy_token`. For example:

        terraform

        import {

          to = gitlab_deploy_token.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        GitLab deploy tokens can be imported using an id made up of `{type}:{type_id}:{deploy_token_id}`, where type is one of: project, group.

        ```sh
        $ pulumi import gitlab:index/deployToken:DeployToken group_token group:1:3
        ```

        ```sh
        $ pulumi import gitlab:index/deployToken:DeployToken project_token project:1:4
        ```

        Note: the `token` resource attribute is not available for imported resources as this information cannot be read from the GitLab API.

        :param str resource_name: The name of the resource.
        :param DeployTokenArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DeployTokenArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 expires_at: Optional[pulumi.Input[str]] = None,
                 group: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 scopes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 username: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DeployTokenArgs.__new__(DeployTokenArgs)

            __props__.__dict__["expires_at"] = expires_at
            __props__.__dict__["group"] = group
            __props__.__dict__["name"] = name
            __props__.__dict__["project"] = project
            if scopes is None and not opts.urn:
                raise TypeError("Missing required property 'scopes'")
            __props__.__dict__["scopes"] = scopes
            __props__.__dict__["username"] = username
            __props__.__dict__["deploy_token_id"] = None
            __props__.__dict__["token"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["token"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(DeployToken, __self__).__init__(
            'gitlab:index/deployToken:DeployToken',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            deploy_token_id: Optional[pulumi.Input[int]] = None,
            expires_at: Optional[pulumi.Input[str]] = None,
            group: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            project: Optional[pulumi.Input[str]] = None,
            scopes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            token: Optional[pulumi.Input[str]] = None,
            username: Optional[pulumi.Input[str]] = None) -> 'DeployToken':
        """
        Get an existing DeployToken resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] deploy_token_id: The id of the deploy token.
        :param pulumi.Input[str] expires_at: Time the token will expire it, RFC3339 format. Will not expire per default.
        :param pulumi.Input[str] group: The name or id of the group to add the deploy token to.
        :param pulumi.Input[str] name: A name to describe the deploy token with.
        :param pulumi.Input[str] project: The name or id of the project to add the deploy token to.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] scopes: Valid values: `read_repository`, `read_registry`, `read_package_registry`, `write_registry`, `write_package_registry`.
        :param pulumi.Input[str] token: The secret token. This is only populated when creating a new deploy token. **Note**: The token is not available for imported resources.
        :param pulumi.Input[str] username: A username for the deploy token. Default is `gitlab+deploy-token-{n}`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DeployTokenState.__new__(_DeployTokenState)

        __props__.__dict__["deploy_token_id"] = deploy_token_id
        __props__.__dict__["expires_at"] = expires_at
        __props__.__dict__["group"] = group
        __props__.__dict__["name"] = name
        __props__.__dict__["project"] = project
        __props__.__dict__["scopes"] = scopes
        __props__.__dict__["token"] = token
        __props__.__dict__["username"] = username
        return DeployToken(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="deployTokenId")
    def deploy_token_id(self) -> pulumi.Output[int]:
        """
        The id of the deploy token.
        """
        return pulumi.get(self, "deploy_token_id")

    @property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> pulumi.Output[Optional[str]]:
        """
        Time the token will expire it, RFC3339 format. Will not expire per default.
        """
        return pulumi.get(self, "expires_at")

    @property
    @pulumi.getter
    def group(self) -> pulumi.Output[Optional[str]]:
        """
        The name or id of the group to add the deploy token to.
        """
        return pulumi.get(self, "group")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        A name to describe the deploy token with.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[Optional[str]]:
        """
        The name or id of the project to add the deploy token to.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter
    def scopes(self) -> pulumi.Output[Sequence[str]]:
        """
        Valid values: `read_repository`, `read_registry`, `read_package_registry`, `write_registry`, `write_package_registry`.
        """
        return pulumi.get(self, "scopes")

    @property
    @pulumi.getter
    def token(self) -> pulumi.Output[str]:
        """
        The secret token. This is only populated when creating a new deploy token. **Note**: The token is not available for imported resources.
        """
        return pulumi.get(self, "token")

    @property
    @pulumi.getter
    def username(self) -> pulumi.Output[str]:
        """
        A username for the deploy token. Default is `gitlab+deploy-token-{n}`.
        """
        return pulumi.get(self, "username")

